#
# spec file for package libdb_java-4_8
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define         generic_name db
%define         major 4
%define         minor 8
Name:           libdb_java-4_8
Version:        %{major}.%{minor}.30
Release:        42.2
Summary:        Java Bindings for the Berkeley DB
License:        BSD-3-Clause AND Sleepycat
Group:          Productivity/Databases/Servers
URL:            https://oracle.com/technetwork/products/berkeleydb/
Source:         http://download.oracle.com/berkeley-db/db-%{version}.tar.gz
Source1:        %{name}.changes
Patch0:         db-%{version}.patch
# PATCH-FIX-OPENSUSE Fix compilation with Java 10 (10-internal)
Patch1:         libdb_java-4_8-fix-java10-comp.patch
# PATCH-FIX-OPENSUSE Fix build with GCC8, conflict with reserved builtin name
Patch2:         libdb-fix-atomic.patch
BuildRequires:  autoconf
BuildRequires:  gcc-c++
BuildRequires:  java-sdk >= 1.8
BuildRequires:  unzip
Requires:       libdb-%{major}_%{minor} = %{version}
Conflicts:      libdb_java-4_5
Provides:       db-java = %{version}

%description
These are the Java bindings for the Berkeley DB. They are needed for
the Java support of db and dbxml.

%package        devel
Summary:        Java Bindings for the Berkeley DB
Group:          Productivity/Databases/Servers
Requires:       %{name} = %{version}
Requires:       glibc-devel
Conflicts:      libdb_java-4_5-devel
Provides:       db-java-devel = %{version}

%description    devel
These are the Java bindings for the Berkeley DB. They are needed for
the Java support of db and dbxml.

These are the development files.

%prep
%setup -q -n %{generic_name}-%{version}
%patch0
%patch1 -p1
%patch2

%build
cd dist
# dist/RELEASE codes the build date into the binary.
# Use last change of changes file instead
LAST_MOD=`stat --format="%%Y" %{SOURCE1}`
DIST_DATE=`date '+%%B %%e, %%Y' --date="@$LAST_MOD"`
sed -i -e "s/^DB_RELEASE_DATE=.*$/DB_RELEASE_DATE=\"$DIST_DATE\"/" RELEASE
./s_config
CFLAGS="%{optflags} -fno-strict-aliasing"
CC=gcc
export CFLAGS CXXFLAGS CC
#
# Build now the NPTL version
#
mkdir ../build_nptl
cd ../build_nptl
%define _configure ../dist/configure
%configure \
        --enable-compat185 --disable-dump185 \
        --enable-shared --disable-static \
        --enable-cxx \
        --with-mutex="POSIX/pthreads/library" \
        --enable-java JAVACFLAGS="-source 1.8 -target 1.8" \
%ifarch %{arm}
        %{_target_cpu}-suse-linux-gnueabi
%else
        %{_target_cpu}-suse-linux
%endif
# Make sure O_DIRECT is really disabled (build host could have old kernel)
perl -pi -e 's/#define HAVE_O_DIRECT 1/#undef HAVE_O_DIRECT/' db_config.h
# Remove libtool predep_objects and postdep_objects wonkiness
perl -pi -e 's/^predep_objects=".*$/predep_objects=""/' libtool
perl -pi -e 's/^postdep_objects=".*$/postdep_objects=""/' libtool
perl -pi -e 's/-shared -nostdlib/-shared/' libtool

make %{?_smp_mflags} LIBSO_LIBS='$(LIBS)' LIBXSO_LIBS='$(LIBS)'" -L%{_libdir} -lstdc++"

%install
mkdir -p %{buildroot}%{_includedir}/db4
mkdir -p %{buildroot}%{_libdir}
cd build_nptl
%make_install STRIP=true
cd ..
# make ldd happy:
chmod 755 %{buildroot}%{_libdir}/libdb*.so
# Fix header file installation
mv %{buildroot}%{_includedir}/*.h %{buildroot}%{_includedir}/db4
echo "#include <db4/db.h>" > %{buildroot}%{_includedir}/db.h
echo "#include <db4/db_185.h>" > %{buildroot}%{_includedir}/db_185.h
echo "#include <db4/db_cxx.h>" > %{buildroot}%{_includedir}/db_cxx.h
# remove dangling tags symlink from examples.
rm -f examples_cxx/tags
rm -f examples_c/tags
# Move documentation to the right directory
mkdir -p %{buildroot}%{_docdir}/%{name}
mv %{buildroot}%{_prefix}/docs/* %{buildroot}/%{_docdir}/%{name}
cp -a examples_cxx examples_c %{buildroot}/%{_docdir}/%{name}
cp -a LICENSE README %{buildroot}/%{_docdir}/%{name}
# Remove api documentation for C++, Java and TCL
rm -rf %{buildroot}/%{_docdir}/%{name}/csharp
rm -rf %{buildroot}/%{_docdir}/%{name}/java
rm -rf %{buildroot}/%{_docdir}/%{name}/api_reference/CXX
rm -rf %{buildroot}/%{_docdir}/%{name}/api_reference/STL
rm -rf %{buildroot}/%{_docdir}/%{name}/api_reference/TCL
rm -rf %{buildroot}/%{_docdir}/%{name}/gsg*/CXX
rm -rf %{buildroot}/%{_docdir}/%{name}/gsg*/JAVA
mv %{buildroot}/%{_docdir}/%{name}/collections/tutorial %{buildroot}/%{_docdir}/%{name}/
# Remove crappy *.la files
find %{buildroot} -type f -name "*.la" -delete -print
pushd %{buildroot}
for file in `find | grep -v "\(java\|jar\)"`
do
  rm $file || true
done
rm -rf %{buildroot}/%{_defaultdocdir}
mkdir -p %{buildroot}/%{_javadir}
mv %{buildroot}/%{_libdir}/*.jar %{buildroot}/%{_javadir}/db-%{version}.jar
ln -sf %{_javadir}/db-%{version}.jar %{buildroot}/%{_javadir}/db.jar

%post -p /sbin/ldconfig
%postun -p /sbin/ldconfig

%files
%{_javadir}/*
%{_libdir}/libdb_java-%{major}.%{minor}.so

%files devel
%{_libdir}/*_g.so
%{_libdir}/libdb_java.so
%{_libdir}/libdb_java-%{major}.so

%changelog
* Wed Jun 21 2023 Pedro Monreal <pmonreal@suse.com>
- Fix incomplete license tag. [bsc#1099695]
* Thu May  4 2023 Frederic Crozat <fcrozat@suse.com>
- Add _multibuild to define additional spec files as additional
  flavors.
  Eliminates the need for source package links in OBS.
* Fri Apr  8 2022 Fridrich Strba <fstrba@suse.com>
- Build with java source and target levels 8
  * fixes build in Factory
* Mon Aug 19 2019 Tomáš Chvátal <tchvatal@suse.com>
- Remove the getpatches as it does not work at all, oracle
  removed the pages
- Use spec-cleaner
- Fix stripped debuginfo to make sure we can debug with libdb
* Mon Apr  9 2018 fstrba@suse.com
- Changed libdb_java-4_8-fix-java10-comp.patch to acount for Java
  10 properly and for following Java versions in a generic way.
* Tue Mar 13 2018 rguenther@suse.com
- Add libdb-fix-atomic.patch to fix __atomic_compare_exchange clash
  with GCCs builtin.  Fixes build with GCC8 which now rejects this.
* Tue Jan  9 2018 pmonrealgonzalez@suse.com
- Added libdb_java-4_8-fix-java10-comp.patch to fix the build with
  Java 10 (10-internal)
* Wed Oct 18 2017 jayvdb@gmail.com
- Remove unnecessary dependency on update-alternatives
* Mon Oct  2 2017 fstrba@suse.com
- Specify java target and soure level 1.6 to allow building with
  jdk9
* Thu Mar 31 2016 tchvatal@suse.com
- Use upstream tarball
- Cleanup with spec-cleaner
- remove unused script check-build.sh
* Mon May 12 2014 schwab@suse.de
- remove generation of unused tarball
- remove setting of unused variable
* Thu Jun 13 2013 jengelh@inai.de
- Add conflict markers against libdb-4_5 (overlapping files)
* Mon Jan  9 2012 aj@suse.de
- Do not use build date as version string.
* Thu Dec 22 2011 jengelh@medozas.de
- Remove redundant/unwanted tags/section (cf. specfile guidelines)
* Tue Sep 27 2011 prusnak@opensuse.org
- spec cleanup
* Sat Aug 13 2011 crrodriguez@opensuse.org
- Disable static libraries
* Wed Sep 22 2010 rhafer@novell.com
- Updated to db-4.8.30. Important changes since 4.7:
  * Improved scalability and throughput when using BTree databases
    especially when running with multiple threads that equal or
    exceed the number of available CPUs.
  * Berkeley DB has added database partitioning. BTree or Hash
    databases may now be partitioned across multiple directories.
    Partitioned databases can be used to increase concurrency and to
    improve performance by spreading access across disk subsystems.
  * Berkeley DB now supports bulk insertion and deletion of data.
    Similar to the bulk get interface, the bulk put and bulk delete
    allow the developer to populate a buffer of key-value pairs and
    then pass it to the BDB library with a single API call.
  * Berkeley DB now supports compression when using BTree.
  * Berkeley DB introduces a new utility named db_sql which replaces
    db_codegen. Similar to db_codegen, db_sql accepts an input file
    with DDL statements and generates a Berkeley DB application
    using the C API that creates and performs CRUD operations on
    the defined tables. The developer can then use that code as a
    basis for further application development.
  * The Replication Manager now supports shared access to the Master
    database environment from multiple processes. In earlier
    versions, multiple process support on the Master required use
    of the Base Replication API.
  * Foreign Key Support has been added to Berkeley DB.
  * for a more detailed changelog see the changelog_4_8.html file
    in db-doc package.
- Removed db-utils-doc subpackage the utils documentation is now
  integrated with the API documentation.
* Wed Aug 26 2009 mls@suse.de
- make patch0 usage consistent
* Fri Nov 21 2008 ro@suse.de
- update check-build.sh
* Wed Jul 30 2008 ro@suse.de
- changed buildreq to use any java > 1.5
* Thu Jul  5 2007 dbornkessel@suse.de
- corrected file list
- added update-alternatives to work around a ia64 problem
* Mon Jun 11 2007 dbornkessel@suse.de
- first version
